@@ -1,5 +1,6 @@
+from revscoring.dependencies import DependentSet
+
 from . import edit, parsed, sentences, tokenized
-from ....dependencies import DependentSet
 
 
 class BaseRevision(DependentSet):
