@@ -89,62 +89,62 @@ def test_entity():
              'ja': ['アラン・テューリング']})
     assert solve(revision.sources, cache={r_text: ALAN_TEXT}) == 56
     assert (solve(revision.datasources.sources, cache={r_text: ALAN_TEXT}) ==
-            {('P108', 'Q220798', 'P248', 0, 'Q20895922'),
-             ('P106', 'Q4964182', 'P143', 0, 'Q48952'),
-             ('P69', 'Q924289', 'P248', 0, 'Q20895922'),
-             ('P570', '+1954-06-07T00:00:00Z', 'P143', 0, 'Q206855'),
-             ('P31', 'Q5', 'P248', 0, 'Q20666306'),
-             ('P800', 'Q20895949', 'P248', 0, 'Q20895922'),
-             ('P25', 'Q20895935', 'P248', 0, 'Q20895922'),
-             ('P349', "'00621580'", 'P143', 0, 'Q48183'),
-             ('P549', "'8014'", 'P143', 0, 'Q328'),
-             ('P569', '+1912-06-23T00:00:00Z', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
-             ('P18', "'Alan Turing Aged 16.jpg'", 'P143', 0, 'Q11920'),
-             ('P569', '+1912-06-23T00:00:00Z', 'P248', 0, 'Q20666306'),
-             ('P19', 'Q122744', 'P143', 0, 'Q328'),
-             ('P214', "'41887917'", 'P143', 0, 'Q8447'),
-             ('P569', '+1912-06-23T00:00:00Z', 'P143', 0, 'Q328'),
-             ('P569', '+1912-06-23T00:00:00Z', 'P345', 0, "'nm6290133'"),
-             ('P91', 'Q6636', 'P248', 0, 'Q20895922'),
-             ('P1273', "'a11455408'", 'P854', 0, "'https://viaf.org/viaf/41887917/'"),
-             ('P1412', 'Q1860', 'P143', 0, 'Q20666306'),
-             ('P69', 'Q2278254', 'P248', 0, 'Q20895922'),
-             ('P31', 'Q5', 'P813', 0, '+2015-10-10T00:00:00Z'),
-             ('P512', 'Q230899', 'P143', 0, 'Q8447'),
-             ('P512', 'Q21578', 'P143', 0, 'Q8447'),
-             ('P1412', 'Q1860', 'P813', 0, '+2015-10-10T00:00:00Z'),
-             ('P1412', 'Q1860', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
-             ('P535', "'12651680'", 'P143', 0, 'Q328'),
-             ('P19', 'Q20895942', 'P248', 0, 'Q20895922'),
-             ('P227', "'118802976'", 'P143', 0, 'Q1419226'),
-             ('P570', '+1954-06-07T00:00:00Z', 'P248', 0, 'Q20666306'),
-             ('P21', 'Q6581097', 'P143', 0, 'Q54919'),
-             ('P800', 'Q20895966', 'P248', 0, 'Q20895922'),
-             ('P935', "'Alan Turing'", 'P143', 0, 'Q191168'),
-             ('P31', 'Q5', 'P143', 0, 'Q206855'),
-             ('P21', 'Q6581097', 'P248', 0, 'Q36578'),
-             ('P646', "'/m/0n00'", 'P248', 0, 'Q15241312'),
-             ('P646', "'/m/0n00'", 'P577', 0, '+2013-10-28T00:00:00Z'),
-             ('P1563', "'Turing'", 'P143', 0, 'Q11921'),
-             ('P19', 'Q122744', 'P854', 0, "'http://www.telegraph.co.uk/technology/news/9314910/Britain-still-owes-Alan-Turing-a-debt.html'"),
-             ('P269', "'030691621'", 'P143', 0, 'Q8447'),
-             ('P108', 'Q230899', 'P248', 0, 'Q20895922'),
-             ('P22', 'Q20895930', 'P248', 0, 'Q20895922'),
-             ('P906', "'254262'", 'P143', 0, 'Q877583'),
-             ('P21', 'Q6581097', 'P813', 0, '+2014-04-09T00:00:00Z'),
-             ('P244', "'n83171546'", 'P143', 0, 'Q328'),
-             ('P570', '+1954-06-07T00:00:00Z', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
-             ('P570', '+1954-06-07T00:00:00Z', 'P813', 0, '+2015-10-10T00:00:00Z'),
-             ('P106', 'Q82594', 'P143', 0, 'Q328'),
-             ('P570', '+1954-06-07T00:00:00Z', 'P345', 0, "'nm6290133'"),
-             ('P213', "'0000 0001 1058 9902'", 'P143', 0, 'Q423048'),
-             ('P31', 'Q5', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
-             ('P569', '+1912-06-23T00:00:00Z', 'P813', 0, '+2015-10-10T00:00:00Z'),
-             ('P1196', 'Q10737', 'P248', 0, 'Q20895922'),
-             ('P268', "'12205670t'", 'P143', 0, 'Q8447'),
-             ('P800', 'Q772056', 'P248', 0, 'Q20895922'),
-             ('P20', 'Q2011497', 'P248', 0, 'Q20895922'),
-             ('P27', 'Q145', 'P143', 0, 'Q48183')})
+            {('P108', 'Q220798', 'P248', 'Q20895922'),
+             ('P106', 'Q4964182', 'P143', 'Q48952'),
+             ('P69', 'Q924289', 'P248', 'Q20895922'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P143', 'Q206855'),
+             ('P31', 'Q5', 'P248', 'Q20666306'),
+             ('P800', 'Q20895949', 'P248', 'Q20895922'),
+             ('P25', 'Q20895935', 'P248', 'Q20895922'),
+             ('P349', "'00621580'", 'P143', 'Q48183'),
+             ('P549', "'8014'", 'P143', 'Q328'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P854', "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P18', "'Alan Turing Aged 16.jpg'", 'P143', 'Q11920'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P248', 'Q20666306'),
+             ('P19', 'Q122744', 'P143', 'Q328'),
+             ('P214', "'41887917'", 'P143', 'Q8447'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P143', 'Q328'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P345', "'nm6290133'"),
+             ('P91', 'Q6636', 'P248', 'Q20895922'),
+             ('P1273', "'a11455408'", 'P854', "'https://viaf.org/viaf/41887917/'"),
+             ('P1412', 'Q1860', 'P143', 'Q20666306'),
+             ('P69', 'Q2278254', 'P248', 'Q20895922'),
+             ('P31', 'Q5', 'P813', '+2015-10-10T00:00:00Z'),
+             ('P512', 'Q230899', 'P143', 'Q8447'),
+             ('P512', 'Q21578', 'P143', 'Q8447'),
+             ('P1412', 'Q1860', 'P813', '+2015-10-10T00:00:00Z'),
+             ('P1412', 'Q1860', 'P854', "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P535', "'12651680'", 'P143', 'Q328'),
+             ('P19', 'Q20895942', 'P248', 'Q20895922'),
+             ('P227', "'118802976'", 'P143', 'Q1419226'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P248', 'Q20666306'),
+             ('P21', 'Q6581097', 'P143', 'Q54919'),
+             ('P800', 'Q20895966', 'P248', 'Q20895922'),
+             ('P935', "'Alan Turing'", 'P143', 'Q191168'),
+             ('P31', 'Q5', 'P143', 'Q206855'),
+             ('P21', 'Q6581097', 'P248', 'Q36578'),
+             ('P646', "'/m/0n00'", 'P248', 'Q15241312'),
+             ('P646', "'/m/0n00'", 'P577', '+2013-10-28T00:00:00Z'),
+             ('P1563', "'Turing'", 'P143', 'Q11921'),
+             ('P19', 'Q122744', 'P854', "'http://www.telegraph.co.uk/technology/news/9314910/Britain-still-owes-Alan-Turing-a-debt.html'"),
+             ('P269', "'030691621'", 'P143', 'Q8447'),
+             ('P108', 'Q230899', 'P248', 'Q20895922'),
+             ('P22', 'Q20895930', 'P248', 'Q20895922'),
+             ('P906', "'254262'", 'P143', 'Q877583'),
+             ('P21', 'Q6581097', 'P813', '+2014-04-09T00:00:00Z'),
+             ('P244', "'n83171546'", 'P143', 'Q328'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P854', "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P570', '+1954-06-07T00:00:00Z', 'P813', '+2015-10-10T00:00:00Z'),
+             ('P106', 'Q82594', 'P143', 'Q328'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P345', "'nm6290133'"),
+             ('P213', "'0000 0001 1058 9902'", 'P143', 'Q423048'),
+             ('P31', 'Q5', 'P854', "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P569', '+1912-06-23T00:00:00Z', 'P813', '+2015-10-10T00:00:00Z'),
+             ('P1196', 'Q10737', 'P248', 'Q20895922'),
+             ('P268', "'12205670t'", 'P143', 'Q8447'),
+             ('P800', 'Q772056', 'P248', 'Q20895922'),
+             ('P20', 'Q2011497', 'P248', 'Q20895922'),
+             ('P27', 'Q145', 'P143', 'Q48183')})
     assert solve(revision.qualifiers, cache={r_text: ALAN_TEXT}) == 6
     assert (solve(revision.datasources.qualifiers, cache={r_text: ALAN_TEXT}) ==
             {('P1343', 'Q17329836', 'P854', 0, "'http://www.larousse.fr/encyclopedie/personnage/Alan_Mathison_Turing/147690'"),
@@ -302,6 +302,65 @@ def test_entity():
              'fa': 'دانشمند کامپیوتر، رمزشکن، منطق\u200cدان و ریاضی' +
              '\u200cدان بریتانیایی',
              'nb': 'britisk informatiker, matematiker og ingeniør'})
+    assert solve(revision.reference_claims, cache={r_text: ALAN_TEXT}) == 56
+    assert (solve(revision.datasources.reference_claims,
+            cache={r_text: ALAN_TEXT}) ==
+            {('P108', 'Q220798', 'P248', 0, 'Q20895922'),
+             ('P106', 'Q4964182', 'P143', 0, 'Q48952'),
+             ('P69', 'Q924289', 'P248', 0, 'Q20895922'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P143', 0, 'Q206855'),
+             ('P31', 'Q5', 'P248', 0, 'Q20666306'),
+             ('P800', 'Q20895949', 'P248', 0, 'Q20895922'),
+             ('P25', 'Q20895935', 'P248', 0, 'Q20895922'),
+             ('P349', "'00621580'", 'P143', 0, 'Q48183'),
+             ('P549', "'8014'", 'P143', 0, 'Q328'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P18', "'Alan Turing Aged 16.jpg'", 'P143', 0, 'Q11920'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P248', 0, 'Q20666306'),
+             ('P19', 'Q122744', 'P143', 0, 'Q328'),
+             ('P214', "'41887917'", 'P143', 0, 'Q8447'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P143', 0, 'Q328'),
+             ('P569', '+1912-06-23T00:00:00Z', 'P345', 0, "'nm6290133'"),
+             ('P91', 'Q6636', 'P248', 0, 'Q20895922'),
+             ('P1273', "'a11455408'", 'P854', 0, "'https://viaf.org/viaf/41887917/'"),
+             ('P1412', 'Q1860', 'P143', 0, 'Q20666306'),
+             ('P69', 'Q2278254', 'P248', 0, 'Q20895922'),
+             ('P31', 'Q5', 'P813', 0, '+2015-10-10T00:00:00Z'),
+             ('P512', 'Q230899', 'P143', 0, 'Q8447'),
+             ('P512', 'Q21578', 'P143', 0, 'Q8447'),
+             ('P1412', 'Q1860', 'P813', 0, '+2015-10-10T00:00:00Z'),
+             ('P1412', 'Q1860', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P535', "'12651680'", 'P143', 0, 'Q328'),
+             ('P19', 'Q20895942', 'P248', 0, 'Q20895922'),
+             ('P227', "'118802976'", 'P143', 0, 'Q1419226'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P248', 0, 'Q20666306'),
+             ('P21', 'Q6581097', 'P143', 0, 'Q54919'),
+             ('P800', 'Q20895966', 'P248', 0, 'Q20895922'),
+             ('P935', "'Alan Turing'", 'P143', 0, 'Q191168'),
+             ('P31', 'Q5', 'P143', 0, 'Q206855'),
+             ('P21', 'Q6581097', 'P248', 0, 'Q36578'),
+             ('P646', "'/m/0n00'", 'P248', 0, 'Q15241312'),
+             ('P646', "'/m/0n00'", 'P577', 0, '+2013-10-28T00:00:00Z'),
+             ('P1563', "'Turing'", 'P143', 0, 'Q11921'),
+             ('P19', 'Q122744', 'P854', 0, "'http://www.telegraph.co.uk/technology/news/9314910/Britain-still-owes-Alan-Turing-a-debt.html'"),
+             ('P269', "'030691621'", 'P143', 0, 'Q8447'),
+             ('P108', 'Q230899', 'P248', 0, 'Q20895922'),
+             ('P22', 'Q20895930', 'P248', 0, 'Q20895922'),
+             ('P906', "'254262'", 'P143', 0, 'Q877583'),
+             ('P21', 'Q6581097', 'P813', 0, '+2014-04-09T00:00:00Z'),
+             ('P244', "'n83171546'", 'P143', 0, 'Q328'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P570', '+1954-06-07T00:00:00Z', 'P813', 0, '+2015-10-10T00:00:00Z'),
+             ('P106', 'Q82594', 'P143', 0, 'Q328'),
+             ('P570', '+1954-06-07T00:00:00Z', 'P345', 0, "'nm6290133'"),
+             ('P213', "'0000 0001 1058 9902'", 'P143', 0, 'Q423048'),
+             ('P31', 'Q5', 'P854', 0, "'http://data.bnf.fr/ark:/12148/cb12205670t'"),
+             ('P569', '+1912-06-23T00:00:00Z', 'P813', 0, '+2015-10-10T00:00:00Z'),
+             ('P1196', 'Q10737', 'P248', 0, 'Q20895922'),
+             ('P268', "'12205670t'", 'P143', 0, 'Q8447'),
+             ('P800', 'Q772056', 'P248', 0, 'Q20895922'),
+             ('P20', 'Q2011497', 'P248', 0, 'Q20895922'),
+             ('P27', 'Q145', 'P143', 0, 'Q48183')})
 
 
 def test_has_property():
